@@ -6,7 +6,7 @@
 	# See the README and LICENSE files for details
 
 	# --------------------------------------------------------
-	# $Id: bug_actiongroup_page.php,v 1.44 2004/11/22 13:36:49 vboctor Exp $
+	# $Id: bug_actiongroup_page.php,v 1.44.2.1 2005/09/25 13:33:48 vboctor Exp $
 	# --------------------------------------------------------
 ?>
 <?php
@@ -14,7 +14,7 @@
 
 	require_once( 'core.php' );
 
-	auth_ensure_user_authenticated(); 
+	auth_ensure_user_authenticated();
 
 	$f_action = gpc_get_string( 'action', '' );
 	$f_bug_arr = gpc_get_int_array( 'bug_arr', array() );
@@ -106,15 +106,15 @@
 <form method="POST" action="bug_actiongroup.php">
 <input type="hidden" name="action" value="<?php echo string_attribute( $f_action ) ?>" />
 <table class="width75" cellspacing="1">
-<?php 
+<?php
 
 $t_bug_rows = "";
 $t_i = 1;
 
-foreach( $f_bug_arr as $t_bug_id ) { 
+foreach( $f_bug_arr as $t_bug_id ) {
 	$t_class = sprintf( "row-%d", ($t_i++ % 2) + 1 );
 	$t_bug_rows .= sprintf( "<tr bgcolor=\"%s\"> <td>%s</td> <td>%s</td> </tr>\n"
-		, get_status_color( bug_get_field( $t_bug_id, 'status' ) ), string_get_bug_view_link( $t_bug_id ), bug_get_field( $t_bug_id, 'summary' ) 
+		, get_status_color( bug_get_field( $t_bug_id, 'status' ) ), string_get_bug_view_link( $t_bug_id ), string_attribute( bug_get_field( $t_bug_id, 'summary' ) )
     );
 	echo '<input type="hidden" name="bug_arr[]" value="' . $t_bug_id . '" />' . "\n";
 }
@@ -158,10 +158,10 @@ if ( !$t_finished ) {
 	if ( isset( $t_question_title2 ) ) {
 		switch ( $f_action ) {
 			case 'RESOLVE':
-				$t_show_version = ( ON == config_get( 'show_product_version' ) ) 
-					|| ( ( AUTO == config_get( 'show_product_version' ) ) 
+				$t_show_version = ( ON == config_get( 'show_product_version' ) )
+					|| ( ( AUTO == config_get( 'show_product_version' ) )
 								&& ( count( version_get_all_rows( $c_project_id ) ) > 0 ) );
-				if ( $t_show_version ) { 
+				if ( $t_show_version ) {
 	?>
 		<tr class="row-2">
 			<td class="category">
@@ -176,7 +176,7 @@ if ( !$t_finished ) {
 	<?php
 				}
 				break;
-		}			
+		}
 	}
 	?>
 <?php
