@@ -6,7 +6,7 @@
 	# See the README and LICENSE files for details
 
 	# --------------------------------------------------------
-	# $Id: bug_assign.php,v 1.38 2004/05/09 02:24:18 vboctor Exp $
+	# $Id: bug_assign.php,v 1.39 2004/10/08 18:57:51 thraxisp Exp $
 	# --------------------------------------------------------
 ?>
 <?php
@@ -23,7 +23,7 @@
 	$f_bug_id = gpc_get_int( 'bug_id' );
 	$f_handler_id = gpc_get_int( 'handler_id', auth_get_current_user_id() );
 
-	access_ensure_bug_level( config_get( 'update_bug_threshold' ), $f_bug_id );
+	access_ensure_bug_level( config_get( 'update_bug_assign_threshold', config_get( 'update_bug_threshold' ) ), $f_bug_id );
 
 	$t_bug_sponsored = sponsorship_get_amount( sponsorship_get_all_ids( $f_bug_id ) ) > 0;
 	if ( $t_bug_sponsored ) {
