@@ -6,27 +6,26 @@
 	# See the README and LICENSE files for details
 
 	# --------------------------------------------------------
-	# $Id: bug_file_delete.php,v 1.27 2004/01/11 07:16:06 vboctor Exp $
+	# $Id: bug_file_delete.php,v 1.29 2004/12/06 20:23:03 marcelloscata Exp $
 	# --------------------------------------------------------
-?>
-<?php
+
 	# Delete a file from a bug and then view the bug
-?>
-<?php
+
 	require_once( 'core.php' );
-	
+
 	$t_core_path = config_get( 'core_path' );
-	
+
 	require_once( $t_core_path.'file_api.php' );
-?>
-<?php
+
 	$f_file_id = gpc_get_int( 'file_id' );
 
 	$t_bug_id = file_get_field( $f_file_id, 'bug_id' );
 
 	access_ensure_bug_level( config_get( 'update_bug_threshold' ), $t_bug_id );
 
-	file_delete( $f_file_id );
+	helper_ensure_confirmed( lang_get( 'delete_attachment_sure_msg' ), lang_get( 'delete_attachment_button' ) );
+
+	file_delete( $f_file_id, 'bug' );
 
 	print_header_redirect_view( $t_bug_id );
 ?>
