@@ -6,7 +6,7 @@
 	# See the README and LICENSE files for details
 
 	# --------------------------------------------------------
-	# $Id: current_user_api.php,v 1.23 2004/11/19 12:29:00 vboctor Exp $
+	# $Id: current_user_api.php,v 1.23.2.1 2005/10/11 12:06:33 vboctor Exp $
 	# --------------------------------------------------------
 
 	$t_core_dir = dirname( __FILE__ ).DIRECTORY_SEPARATOR;
@@ -78,7 +78,8 @@
 	# --------------------
 	# Return true if the currently user is the anonymous user
 	function current_user_is_anonymous() {
-		return current_user_get_field( 'username' ) == config_get( 'anonymous_account' );
+		$t_anonymous_account = config_get( 'anonymous_account' );
+		return ( !is_blank( $t_anonymous_account ) && ( current_user_get_field( 'username' ) == $t_anonymous_account ) );
 	}
 	# --------------------
 	# Trigger an ERROR if the current user account is protected
