@@ -6,7 +6,7 @@
 	# See the README and LICENSE files for details
 
 	# --------------------------------------------------------
-	# $Id: email_api.php,v 1.102 2004/10/05 21:10:14 prichards Exp $
+	# $Id: email_api.php,v 1.102.4.1 2005/09/25 13:50:29 vboctor Exp $
 	# --------------------------------------------------------
 
 	$t_core_dir = dirname( __FILE__ ).DIRECTORY_SEPARATOR;
@@ -576,7 +576,7 @@
 
 		# short-circuit if no recipient is defined, or email disabled
 		# note that this may cause signup messages not to be sent
-		
+
 		if ( is_blank( $p_recipient ) || ( OFF == config_get( 'enable_email_notification' ) ) ) {
 			return;
 		}
@@ -598,7 +598,7 @@
 		$mail = new PHPMailer;
 
 		$mail->PluginDir = PHPMAILER_PATH;
-		# @@@ should this be the current language (for the recipient) or the default one (for the user running the command) (thraxisp) 
+		# @@@ should this be the current language (for the recipient) or the default one (for the user running the command) (thraxisp)
 		$mail->SetLanguage( lang_get( 'phpmailer_language', lang_get_current() ), PHPMAILER_PATH . 'language' . DIRECTORY_SEPARATOR );
 
 		# Select the method to send mail
@@ -768,20 +768,28 @@
 			$p_recipients = array( $p_recipients );
 		}
 
+		$t_project_id = bug_get_field( $p_bug_id, 'project_id' );
+		$t_sender_id = auth_get_current_user_id();
+		$t_sender = user_get_name( $t_sender_id );
+
+		$t_subject = email_build_subject( $p_bug_id );
+		$t_date = date( config_get( 'normal_date_format' ) );
+
 		$result = array();
 		foreach ( $p_recipients as $t_recipient ) {
-
-			lang_push( user_pref_get_language( $t_recipient, bug_get_field( $p_bug_id, 'project_id' ) ) );
-
-			$t_subject = email_build_subject( $p_bug_id );
-			$t_sender = current_user_get_field( 'username' ) . ' <' .
-						current_user_get_field( 'email' ) . '>' ;
-			$t_date = date( config_get( 'normal_date_format' ) );
-			$t_header = "\n" . lang_get( 'on' ) . " $t_date, $t_sender " .
-						lang_get( 'sent_you_this_reminder_about' ) . ":\n\n";
+			lang_push( user_pref_get_language( $t_recipient, $t_project_id ) );
 
 			$t_email = user_get_email( $t_recipient );
 			$result[] = user_get_name( $t_recipient );
+
+			if ( access_has_project_level( config_get( 'show_user_email_threshold' ), $t_project_id, $t_recipient ) ) {
+				$t_sender_email .= ' <' . current_user_get_field( 'email' ) . '>' ;
+			} else {
+				$t_sender_email = '';
+			}
+			$t_header = "\n" . lang_get( 'on' ) . " $t_date, $t_sender $t_sender_email " .
+						lang_get( 'sent_you_this_reminder_about' ) . ": \n\n";
+
 			$t_contents = $t_header .
 							string_get_bug_view_url_with_fqdn( $p_bug_id, $t_recipient ) .
 							"\n\n$p_message";
