@@ -6,7 +6,7 @@
 	# See the README and LICENSE files for details
 
 	# --------------------------------------------------------
-	# $Id: file_api.php,v 1.60 2004/10/17 01:58:57 thraxisp Exp $
+	# $Id: file_api.php,v 1.60.6.1 2005/11/21 02:45:53 thraxisp Exp $
 	# --------------------------------------------------------
 
 	$t_core_dir = dirname( __FILE__ ).DIRECTORY_SEPARATOR;
@@ -540,6 +540,14 @@
 				global $HTTP_POST_FILES;
 				$t_file_size = $HTTP_POST_FILES['file']['size'];
 			}
+			$t_file_size = filesize( $p_tmp_file );
+	    	if ( 0 == $t_file_size ) {
+		    	trigger_error( ERROR_FILE_NO_UPLOAD_FAILURE, ERROR );
+        	}
+			$t_max_file_size = (int)min( ini_get_number( 'upload_max_filesize' ), ini_get_number( 'post_max_size' ), config_get( 'max_file_size' ) );
+        	if ( $t_file_size > $t_max_file_size ) {
+            	trigger_error( ERROR_FILE_TOO_BIG, ERROR );
+        	}
 			$c_file_size = db_prepare_int( $t_file_size );
 
 			$t_method			= config_get( 'file_upload_method' );
