@@ -6,7 +6,7 @@
 	# See the README and LICENSE files for details
 
 	# --------------------------------------------------------
-	# $Id: filter_api.php,v 1.64 2004/11/19 13:06:29 vboctor Exp $
+	# $Id: filter_api.php,v 1.64.2.1.2.1 2005/12/12 03:00:05 thraxisp Exp $
 	# --------------------------------------------------------
 
 	$t_core_dir = dirname( __FILE__ ).DIRECTORY_SEPARATOR;
@@ -56,13 +56,13 @@
 		$t_report_bug_threshold		= config_get( 'report_bug_threshold' );
 
 		$t_current_user_id = auth_get_current_user_id();
-		
+
 		if ( null === $p_user_id ) {
 			$t_user_id = $t_current_user_id;
 		} else {
 			$t_user_id = $p_user_id;
 		}
-		
+
 		$c_user_id = db_prepare_int( $t_user_id );
 
 		if ( null === $p_project_id ) {
@@ -320,7 +320,7 @@
 			array_push( $t_where_clauses, '('. implode( ' OR ', $t_clauses ) .')' );
 		}
 
-		# priority 
+		# priority
 		$t_any_found = false;
 		foreach( $t_filter['show_priority'] as $t_filter_member ) {
 				if ( 'any' == $t_filter_member ) {
@@ -466,7 +466,7 @@
 					$t_any_found = true;
 				}
 				if ( !$t_any_found ) {
-					$t_def = custom_field_get_definition( $t_cfid );				
+					$t_def = custom_field_get_definition( $t_cfid );
 					$t_table_name = $t_custom_field_string_table . '_' . $t_cfid;
 					array_push( $t_join_clauses, "LEFT JOIN $t_custom_field_string_table as $t_table_name ON $t_table_name.bug_id = $t_bug_table.id" );
 					foreach( $t_filter['custom_fields'][$t_cfid] as $t_filter_member ) {
@@ -521,7 +521,7 @@
 							 OR ($t_bug_text_table.additional_information LIKE '%$c_search%')
 							 OR ($t_bug_table.id LIKE '%$c_search%')
 							 OR ($t_bugnote_text_table.note LIKE '%$c_search%'))";
-							 
+
 			array_push( $t_where_clauses, "($t_bug_text_table.id = $t_bug_table.bug_text_id)" );
 
 			$t_from_clauses = array( $t_bug_text_table, $t_project_table, $t_bug_table );
@@ -669,7 +669,7 @@
 			$row = db_fetch_array( $result2 );
 			$row['date_submitted'] = db_unixtimestamp ( $row['date_submitted'] );
 			$row['last_updated'] = db_unixtimestamp ( $row['last_updated'] );
-	
+
 			array_push( $rows, $row );
 			bug_add_to_cache( $row );
 		}
@@ -744,16 +744,16 @@
 		$t_tdclass = 'small-caption';
 		$t_trclass = 'row-category2';
 		$t_action  = 'view_all_set.php?f=3';
-		
+
 		if ( $p_for_screen == false ) {
 			$t_tdclass = 'print';
 			$t_trclass = '';
 			$t_action  = 'view_all_set.php';
 		}
-?> 
+?>
 
 		<br />
-		<form method="post" name="filters" action="<?php PRINT $t_action; ?>">
+		<form method="post" name="filters" action="<?php PRINT htmlentities($t_action); ?>">
 		<input type="hidden" name="type" value="5" />
 		<?php
 			if ( $p_for_screen == false ) {
@@ -761,12 +761,12 @@
 				PRINT '<input type="hidden" name="offset" value="0" />';
 			}
 		?>
-		<input type="hidden" name="sort" value="<?php PRINT $t_sort ?>" />
-		<input type="hidden" name="dir" value="<?php PRINT $t_dir ?>" />
-		<input type="hidden" name="page_number" value="<?php PRINT $p_page_number ?>" />
-		<input type="hidden" name="view_type" value="<?php PRINT $t_view_type ?>" />
+		<input type="hidden" name="sort" value="<?php PRINT htmlentities($t_sort) ?>" />
+		<input type="hidden" name="dir" value="<?php PRINT htmlentities($t_dir) ?>" />
+		<input type="hidden" name="page_number" value="<?php PRINT htmlentities($p_page_number) ?>" />
+		<input type="hidden" name="view_type" value="<?php PRINT htmlentities($t_view_type) ?>" />
 		<table class="width100" cellspacing="1">
-		
+
 		<?php
 		if ( $p_expanded ) {
 			$t_filter_cols = 7;
@@ -827,7 +827,7 @@
 				<a href="<?php PRINT $t_filters_url . 'show_resolution[]'; ?>"><?php PRINT lang_get( 'resolution' ) ?>:</a>
 			</td>
 
-			<?php 
+			<?php
 				if ( $t_custom_cols > $t_filter_cols ) {
 					echo '<td colspan="' . ($t_custom_cols - $t_filter_cols) . '">&nbsp;</td>';
 				}
@@ -961,7 +961,7 @@
 										if ( ( $t_current == 'any' ) || ( is_blank( $t_current ) ) ) {
 											$t_any_found = true;
 										} else {
-											$t_this_string = $t_current;
+											$t_this_string = string_display( $t_current );
 										}
 										if ( $t_first_flag != true ) {
 											$t_output = $t_output . '<br>';
@@ -1038,7 +1038,7 @@
 								}
 							?>
 			</td>
-			<?php 
+			<?php
 				if ( $t_custom_cols > $t_filter_cols ) {
 					echo '<td colspan="' . ($t_custom_cols - $t_filter_cols) . '">&nbsp;</td>';
 				}
@@ -1144,7 +1144,7 @@
 										if ( ( $t_current == 'any' ) || ( is_blank( $t_current ) ) ) {
 											$t_any_found = true;
 										} else {
-											$t_this_string = $t_current;
+											$t_this_string = string_display( $t_current );
 										}
 										if ( $t_first_flag != true ) {
 											$t_output = $t_output . '<br>';
@@ -1204,7 +1204,7 @@
 										if ( ( $t_current == 'any' ) || ( is_blank( $t_current ) ) ) {
 											$t_any_found = true;
 										} else {
-											$t_this_string = $t_current;
+											$t_this_string = string_display( $t_current );
 										}
 										if ( $t_first_flag != true ) {
 											$t_output = $t_output . '<br>';
@@ -1266,7 +1266,7 @@
 			<td class="small-caption" valign="top" colspan="4">
 				<a href="<?php PRINT $t_filters_url . 'do_filter_by_date'; ?>"><?php PRINT lang_get( 'use_date_filters' ) ?>:</a>
 			</td>
-			<?php 
+			<?php
 				if ( $t_custom_cols > $t_filter_cols ) {
 					echo '<td colspan="' . ($t_custom_cols - $t_filter_cols) . '">&nbsp;</td>';
 				}
@@ -1332,7 +1332,7 @@
 							}
 							?>
 			</td>
-			<?php 
+			<?php
 				if ( $t_custom_cols > $t_filter_cols ) {
 					echo '<td colspan="' . ($t_custom_cols - $t_filter_cols) . '">&nbsp;</td>';
 				}
@@ -1368,7 +1368,7 @@
 					$t_output = '';
 					$t_any_found = false;
 
-					$t_values .= '<td class="small-caption" valign="top"> ' ; 
+					$t_values .= '<td class="small-caption" valign="top"> ' ;
 					if ( !isset( $t_filter['custom_fields'][$t_accessible_custom_fields_ids[$i]] ) ) {
 						$t_values .= lang_get( 'any' );
 					} else {
@@ -1410,7 +1410,7 @@
 						$t_values .= '</tr>' . "\n";
 
 						echo $t_fields;
-						echo $t_values; 
+						echo $t_values;
 
 						$t_col_idx = 0;
 						$t_row_idx++;
@@ -1433,7 +1433,7 @@
 					$t_values .= '</tr>' . "\n";
 
 					echo $t_fields;
-					echo $t_values; 
+					echo $t_values;
 				}
 			}
 		}
@@ -1445,7 +1445,7 @@
 				<?php
 					collapse_icon( 'filter' );
 					echo lang_get( 'search' );
-				?>: 
+				?>:
 				<input type="text" size="16" name="search" value="<?php PRINT htmlspecialchars( $t_filter['search'] ); ?>" />
 
 				<input type="submit" name="filter" class="button" value="<?php PRINT lang_get( 'search' ) ?>" />
@@ -1521,7 +1521,7 @@
 		$t_filters_table = config_get( 'mantis_filters_table' );
 
 		# check that the user can save non current filters (if required)
-		if ( ( ALL_PROJECTS <= $c_project_id ) && ( !is_blank( $p_name ) ) && 
+		if ( ( ALL_PROJECTS <= $c_project_id ) && ( !is_blank( $p_name ) ) &&
 		     ( !access_has_project_level( config_get( 'stored_query_create_threshold' ) ) ) ) {
 			return -1;
 		}
@@ -1587,7 +1587,7 @@
 		if ( isset( $g_cache_filter_db_filters[$p_filter_id] ) ) {
 			return $g_cache_filter_db_filters[$p_filter_id];
 		}
-		
+
 		if ( null === $p_user_id ) {
 			$t_user_id = auth_get_current_user_id();
 		} else {
@@ -1722,7 +1722,7 @@
 		$t_all_id = ALL_PROJECTS;
 
 		$query = "DELETE FROM $t_filters_table
-					WHERE project_id<='$t_all_id' 
+					WHERE project_id<='$t_all_id'
 					AND name=''";
 		$result = db_query( $query );
 	}
@@ -1730,7 +1730,7 @@
 	function filter_db_get_available_queries( $p_project_id = null, $p_user_id = null ) {
 		$t_filters_table = config_get( 'mantis_filters_table' );
 		$t_overall_query_arr = array();
-		
+
 		if ( null === $p_project_id ) {
 			$t_project_id = helper_get_current_project();
 		} else {
