@@ -6,13 +6,14 @@
 	# See the README and LICENSE files for details
 
 	# --------------------------------------------------------
-	# $Id: print_api.php,v 1.99 2004/08/24 01:44:26 thraxisp Exp $
+	# $Id: print_api.php,v 1.107 2004/11/30 12:17:03 vboctor Exp $
 	# --------------------------------------------------------
 
 	$t_core_dir = dirname( __FILE__ ).DIRECTORY_SEPARATOR;
 
 	require_once( $t_core_dir . 'current_user_api.php' );
 	require_once( $t_core_dir . 'string_api.php' );
+	require_once( $t_core_dir . 'prepare_api.php' );
 
 	### Print API ###
 
@@ -92,22 +93,7 @@
 	# --------------------
 	# prints the name of the user given the id.  also makes it an email link.
 	function print_user( $p_user_id ) {
-		# Catch a user_id of NO_USER (like when a handler hasn't been assigned)
-		if ( NO_USER == $p_user_id ) {
-			return;
-		}
-
-		$t_username = user_get_name( $p_user_id );
-		if ( user_exists( $p_user_id ) ) {
-			$t_email = user_get_email( $p_user_id );
-			if ( !is_blank( $t_email ) ) {
-				print_email_link( $t_email, $t_username );
-			} else {
-				PRINT $t_username;
-			}
-		} else {
-			PRINT $t_username;
-		}
+	    echo prepare_user_name( $p_user_id );
 	}
 	# --------------------
 	# same as print_user() but fills in the subject with the bug summary
@@ -119,11 +105,13 @@
 		}
 
 		$t_username = user_get_name( $p_user_id );
-		if ( user_exists( $p_user_id ) ) {
+		if ( user_exists( $p_user_id ) && user_get_field( $p_user_id, 'enabled' ) ) {
 			$t_email = user_get_field( $p_user_id, 'email' );
 			print_email_link_with_subject( $t_email, $t_username, $p_bug_id );
 		} else {
-			PRINT $t_username;
+			echo '<font STYLE="text-decoration: line-through">';
+			echo $t_username;
+			echo '</font>';
 		}
 	}
 	# --------------------
@@ -222,15 +210,19 @@
 			$t_users = project_get_all_user_rows( $p_project_id );
 		}
 
+		$t_display = array();
 		foreach ( $t_users as $t_user ) {
 			$t_user_name = string_attribute( $t_user['username'] );
-			if ( isset( $t_user['realname'] ) && $t_user['realname'] > "" ) {
+			if ( ( isset( $t_user['realname'] ) ) && ( $t_user['realname'] > "" ) && ( ON == config_get( 'show_realname' ) ) ){
 				$t_user_name = string_attribute( $t_user['realname'] );
 			}
-
-			PRINT '<option value="' . $t_user['id'] . '" ';
-			check_selected( $p_user_id, $t_user['id'] );
-			PRINT '>' . $t_user_name . '</option>';
+			$t_display[$t_user['id']] = $t_user_name;
+		}
+		natcasesort( $t_display );
+		foreach ($t_display as $t_id => $t_name ) {
+			PRINT '<option value="' . $t_id . '" ';
+			check_selected( $p_user_id, $t_id );
+			PRINT '>' . $t_name . '</option>';
 		}
 	}
 
@@ -319,7 +311,6 @@
 		# checking if it's per project or all projects
 		if ( ALL_PROJECTS == $p_project_id ) {
 			$t_adm = ADMINISTRATOR;
-			$t_dev = config_get( 'handle_bug_threshold' );
 			$t_pub = VS_PUBLIC;
 			$t_prv = VS_PRIVATE;
 
@@ -348,15 +339,19 @@
 			$t_users = project_get_all_user_rows( $p_project_id, $p_threshold );
 		}
 
+		$t_display = array();
 		foreach ( $t_users as $t_user ) {
 			$t_user_name = string_attribute( $t_user['username'] );
-			if ( isset( $t_user['realname'] ) && $t_user['realname'] > "" ) {
+			if ( ( isset( $t_user['realname'] ) ) && ( $t_user['realname'] > "" ) && ( ON == config_get( 'show_realname' ) ) ){
 				$t_user_name = string_attribute( $t_user['realname'] );
 			}
-
-			PRINT '<option value="' . $t_user['id'] . '" ';
-			check_selected( $p_user_id, $t_user['id'] );
-			PRINT '>' . $t_user_name . '</option>';
+			$t_display[$t_user['id']] = $t_user_name;
+		}
+		natcasesort( $t_display );
+		foreach ($t_display as $t_id => $t_name ) {
+			PRINT '<option value="' . $t_id . '" ';
+			check_selected( $p_user_id, $t_id );
+			PRINT '>' . $t_name . '</option>';
 		}
 	}
 	# --------------------
@@ -592,34 +587,47 @@
 	# or the input parameter if workflows are not used
 	# $p_enum_name : name of enumeration (eg: status)
 	# $p_current_value : current value
-	function print_status_option_list( $p_select_label, $p_current_value = 0 ) {
+	function get_status_option_list( $p_user_auth = 0, $p_current_value = 0, $p_show_current = true, $p_add_close = false ) {
 		$t_config_var_value = config_get( 'status_enum_string' );
 		$t_enum_workflow = config_get( 'status_enum_workflow' );
-		$t_current_auth = access_get_project_level();
 
 		if ( count( $t_enum_workflow ) < 1 ) {
 			# workflow not defined, use default enum
 			$t_arr  = explode_enum_string( $t_config_var_value );
 		} else {
 			# workflow defined - find allowed states
-			$t_arr  = explode_enum_string( $t_enum_workflow[$p_current_value] );
+			if ( isset( $t_enum_workflow[$p_current_value] ) ) {
+				$t_arr  = explode_enum_string( $t_enum_workflow[$p_current_value] );
+			}else{
+				# workflow was not set for this status, this shouldn't happen
+				$t_arr  = explode_enum_string( $t_config_var_value );
+			}
 		}
 
 		$t_enum_count = count( $t_arr );
 		$t_enum_list = array();
-		$t_current_state = '';
 
 		for ( $i = 0; $i < $t_enum_count; $i++ ) {
 			$t_elem  = explode_enum_arr( $t_arr[$i] );
-			$t_elem2 = get_enum_element( 'status', $t_elem[0] );
-			$t_status = $t_elem[0];
-			if ( $t_status == $p_current_value ) {
-				$t_current_state = $t_elem2;
-			}
-			if ( $t_current_auth >= access_get_status_threshold( $t_status ) ) {
-				$t_enum_list[$t_status] = $t_elem2;
+			if ( ( $p_user_auth >= access_get_status_threshold( $t_elem[0] ) ) &&
+						( ! ( ( false == $p_show_current ) && ( $p_current_value == $t_elem[0] ) ) ) ) {
+				$t_enum_list[$t_elem[0]] = get_enum_element( 'status', $t_elem[0] );
 			}
 		} # end for
+		if ( true == $p_show_current ) {
+				$t_enum_list[$p_current_value] = get_enum_element( 'status', $p_current_value );
+			}
+		if ( ( true == $p_add_close ) && ( $p_current_value >= config_get( 'bug_resolved_status_threshold' ) ) ) {
+				$t_enum_list[CLOSED] = get_enum_element( 'status', CLOSED );
+			}
+		return $t_enum_list;
+	}
+	# --------------------
+	# print the status option list for the bug_update pages
+	function print_status_option_list( $p_select_label, $p_current_value = 0, $p_allow_close = false, $p_project_id = null ) {
+		$t_current_auth = access_get_project_level( $p_project_id );
+
+		$t_enum_list = get_status_option_list( $t_current_auth, $p_current_value, true, $p_allow_close );
 
 		if ( count( $t_enum_list ) > 0 ) {
 			echo '<select name="' . $p_select_label . '">';
@@ -630,7 +638,7 @@
 			}
 			echo '</select>';
 		} else {
-			echo $t_current_state;
+			echo get_enum_to_string( 'status_enum_string', $p_current_value );
 		}
 
 	}
@@ -658,6 +666,11 @@
 	function print_project_access_levels_option_list( $p_val ) {
 		global $g_mantis_project_table, $g_access_levels_enum_string;
 
+		# Add [default access level] to add the user to a project
+		# with his default access level.
+		PRINT "<option value=\"" . DEFAULT_ACCESS_LEVEL . "\"";
+		PRINT ">[" . lang_get( 'default_access_level' ) . "]</option>";
+
 		$t_arr = explode_enum_string( $g_access_levels_enum_string );
 		$enum_count = count( $t_arr );
 		for ($i=0;$i<$enum_count;$i++) {
@@ -1062,17 +1075,7 @@
 	# --------------------
 	# return the mailto: href string link instead of printing it
 	function get_email_link( $p_email, $p_text ) {
-		if ( !access_has_project_level( config_get( 'show_user_email_threshold' ) ) ) {
-			return $p_text;
-		}
-
-		# If we apply string_url() to the whole mailto: link then the @
-		#  gets turned into a %40 and you can't right click in browsers to
-		#  do Copy Email Address.
-		$t_mailto	= string_attribute( "mailto:$p_email" );
-		$p_text		= string_display( $p_text );
-
-		return "<a href=\"$t_mailto\">$p_text</a>";
+	    return prepare_email_link( $p_email, $p_text );
 	}
 	# --------------------
 	# print a mailto: href link with subject
