@@ -6,7 +6,7 @@
 	# See the README and LICENSE files for details
 
 	# --------------------------------------------------------
-	# $Id: string_api.php,v 1.62 2004/12/11 03:57:02 thraxisp Exp $
+	# $Id: string_api.php,v 1.62.4.1 2005/12/05 12:12:05 vboctor Exp $
 	# --------------------------------------------------------
 
 	$t_core_dir = dirname( __FILE__ ).DIRECTORY_SEPARATOR;
@@ -56,7 +56,7 @@
 			return $p_string;
 		}
 	}
-	
+
 	# --------------------
 	# Similar to nl2br, but fixes up a problem where new lines are doubled between
 	# <pre> tags.
@@ -180,7 +180,7 @@
 		if ( '' == $t_tag ) {
 			return $p_string;
 		}
-		
+
 		$t_path = config_get( 'path' );
 
 		preg_match_all( '/(^|.+?)(?:(?<=^|\W)' . preg_quote($t_tag, '/') . '(\d+)|$)/s',
@@ -219,7 +219,7 @@
 
 		return $t_result;
 	}
-	
+
 	# --------------------
 	# Process $p_string, looking for bugnote ID references and creating bug view
 	#  links for them.
@@ -291,9 +291,9 @@
 		if ( !config_get( 'html_make_links' ) ) {
 			return $p_string;
 		}
-		# Find any URL in a string and replace it by a clickable link		
+		# Find any URL in a string and replace it by a clickable link
 		$p_string = preg_replace( '/([http|irc|ftp|https]{2,}:\/\/([a-z0-9_-]|\/|\@|:{0,1}\.{0,1}){1,})/',
-									'<a href="\1">\1</a> [<a href="\1" target="blank">^</a>]',   
+									'<a href="\1">\1</a> [<a href="\1" target="blank">^</a>]',
 									$p_string);
 
 		# Set up a simple subset of RFC 822 email address parsing
@@ -423,7 +423,7 @@
 
 		return $t_link;
 	}
-	
+
 	# --------------------
 	# return an href anchor that links to a bug VIEW page for the given bug
 	#  account for the user preference and site override
@@ -444,14 +444,14 @@
 
 		return $t_link;
 	}
-	
+
 	# --------------------
 	# return the name and GET parameters of a bug VIEW page for the given bug
 	#  account for the user preference and site override
 	function string_get_bug_view_url( $p_bug_id, $p_user_id = null ) {
 		return 'view.php?id=' . $p_bug_id;
 	}
-	
+
 	# --------------------
 	# return the name and GET parameters of a bug VIEW page for the given bug
 	#  account for the user preference and site override
@@ -467,7 +467,7 @@
 	function string_get_bugnote_view_url_with_fqdn( $p_bug_id, $p_bugnote_id, $p_user_id = null ) {
 		return config_get( 'path' ) . string_get_bug_view_url( $p_bug_id, $p_user_id ).'#'.$p_bugnote_id;
 	}
-	
+
 	# --------------------
 	# return the name and GET parameters of a bug VIEW page for the given bug
 	#  account for the user preference and site override
@@ -548,4 +548,22 @@
 		$t_timestamp = db_unixtimestamp( $p_date );
 		return date( config_get( 'complete_date_format' ), $t_timestamp );
 	}
-?>
+
+	# --------------------
+	# Prepares a string to be used as part of header().
+	function string_prepare_header( $p_string ) {
+		$t_string = $p_string;
+
+		$t_truncate_pos = strpos($p_string, "\n");
+		if ($t_truncate_pos !== false ) {
+			$t_string = substr($t_string, 0, $t_truncate_pos);
+		}
+
+		$t_truncate_pos = strpos($p_string, "\r");
+		if ($t_truncate_pos !== false ) {
+			$t_string = substr($t_string, 0, $t_truncate_pos);
+		}
+
+		return $t_string;
+	}
+?>
\ No newline at end of file
