@@ -6,7 +6,7 @@
 	# See the README and LICENSE files for details
 
 	# --------------------------------------------------------
-	# $Id: login_cookie_test.php,v 1.8 2004/08/05 17:58:47 jlatour Exp $
+	# $Id: login_cookie_test.php,v 1.8.20.1 2005/12/05 12:12:05 vboctor Exp $
 	# --------------------------------------------------------
 ?>
 <?php
@@ -16,11 +16,13 @@
 <?php
 	$f_return = gpc_get_string( 'return', config_get( 'default_home_page' ) );
 
+	$c_return = string_prepare_header( $f_return );
+
 	if ( auth_is_user_authenticated() ) {
-		$t_redirect_url = $f_return;
+		$t_redirect_url = $c_return;
 	} else {
 		$t_redirect_url = 'login_page.php?cookie_error=1';
 	}
 
 	print_header_redirect( $t_redirect_url );
-?>
+?>
\ No newline at end of file
