@@ -6,7 +6,7 @@
 	# See the README and LICENSE files for details
 
 	# --------------------------------------------------------
-	# $Id: lost_pwd.php,v 1.3 2004/10/25 19:45:04 marcelloscata Exp $
+	# $Id: lost_pwd.php,v 1.3.4.1 2005/09/22 11:11:35 vboctor Exp $
 	# --------------------------------------------------------
 
 	# ======================================================================
@@ -27,9 +27,12 @@
 	$f_email = email_append_domain( $f_email );
 	email_ensure_valid( $f_email );
 
+	$c_username = db_prepare_string( $f_username );
+	$c_email = db_prepare_string( $f_email );
+
 	$t_user_table = config_get( 'mantis_user_table' );
 
-	$query = 'SELECT id FROM ' . $t_user_table . ' WHERE username = \'' . $f_username . '\' and email = \'' . $f_email . '\'';
+	$query = 'SELECT id FROM ' . $t_user_table . ' WHERE username = \'' . $c_username . '\' and email = \'' . $c_email . '\'';
 	$result = db_query( $query );
 
 	if ( 0 == db_num_rows( $result ) ) {
