@@ -6,14 +6,14 @@
 	# See the README and LICENSE files for details
 
 	# --------------------------------------------------------
-	# $Id: set_project.php,v 1.49 2004/10/24 02:40:01 vboctor Exp $
+	# $Id: set_project.php,v 1.49.6.1 2005/12/05 12:12:05 vboctor Exp $
 	# --------------------------------------------------------
 ?>
 <?php
 	require_once( 'core.php' );
-	
+
 	$t_core_path = config_get( 'core_path' );
-	
+
 	require_once( $t_core_path.'current_user_api.php' );
 ?>
 <?php
@@ -21,6 +21,8 @@
 	$f_make_default	= gpc_get_bool( 'make_default' );
 	$f_ref			= gpc_get_string( 'ref', '' );
 
+	$c_ref = string_prepare_header( $f_ref );
+
 	if ( ALL_PROJECTS != $f_project_id ) {
 		project_ensure_exists( $f_project_id );
 	}
@@ -40,8 +42,8 @@
 	# redirect to 'same page' when switching projects.
 	# view_all_* pages, and summary
 	# for proxies that clear out HTTP_REFERER
-	if ( !is_blank( $f_ref ) ) {
-		$t_redirect_url = $f_ref;
+	if ( !is_blank( $c_ref ) ) {
+		$t_redirect_url = $c_ref;
 	} else if ( !isset( $_SERVER['HTTP_REFERER'] ) || is_blank( $_SERVER['HTTP_REFERER'] ) ) {
 		$t_redirect_url = config_get( 'default_home_page' );
 	} else if ( eregi( 'view_all_bug_page.php', $_SERVER['HTTP_REFERER'] ) ){
@@ -50,7 +52,7 @@
 
 		if ( $t_source_filter_id != null ) {
 			$t_redirect_url = 'view_all_set.php?type=3&source_query_id=' . $t_source_filter_id;
-		} 
+		}
 	} else if ( eregi( 'changelog_page.php', $_SERVER['HTTP_REFERER'] ) ){
 		$t_redirect_url =  'changelog_page.php';
 	} else if ( eregi( 'summary_page.php', $_SERVER['HTTP_REFERER'] ) ){
