@@ -23,8 +23,37 @@
 	html_page_top1();
 	html_page_top2();
 
+	$t_project_id = helper_get_current_project();
 	$t_target_field = gpc_get_string( 'target_field', '' );
+	$t_fields = array( 'priority', 'id', 'sponsorship_total', 'category', 'severity', 'status', 'last_updated', 'summary' );
+	$t_accessible_custom_fields_ids = array();
+	$t_accessible_custom_fields_names = array();
+	$t_accessible_custom_fields_values = array();
 
+	if ( ON == config_get( 'filter_by_custom_fields' ) ) {
+		$t_custom_cols = config_get( 'filter_custom_fields_per_row' );
+		$t_custom_fields = custom_field_get_ids( $t_project_id );
+
+		foreach ( $t_custom_fields as $t_cfid ) {
+			$t_field_info = custom_field_cache_row( $t_cfid, true );
+			if ( $t_field_info['access_level_r'] <= $t_current_user_access_level ) {
+				$t_accessible_custom_fields_ids[] = $t_cfid;
+				$t_accessible_custom_fields_names[] = $t_field_info['name'];
+				$t_accessible_custom_fields_values[] = custom_field_distinct_values( $t_cfid, $t_project_id );
+				$t_fields[] = "custom_" . $t_field_info['name'];
+			}
+		}
+
+		if ( sizeof( $t_accessible_custom_fields_ids ) > 0 ) {
+			$t_per_row = config_get( 'filter_custom_fields_per_row' );
+			$t_custom_rows = ceil( sizeof( $t_accessible_custom_fields_ids ) / $t_per_row );
+		}
+	}		
+
+ 	if ( ! in_array( $t_target_field, $t_fields ) ) {
+ 		$t_target_field = '';
+ 	}
+ 	
 	if ( ON == config_get( 'use_javascript' ) ) {
 		?>
 		<body onload="SetInitialFocus();">
@@ -69,46 +98,22 @@
 	
 	$t_filter = current_user_get_bug_filter();
 	$t_filter = filter_ensure_valid_filter( $t_filter );
-	$t_project_id = helper_get_current_project();
 
 	$t_sort = $t_filter['sort'];
 	$t_dir = $t_filter['dir'];
 	
 	$t_current_user_access_level = current_user_get_access_level();
-	$t_accessible_custom_fields_ids = array();
-	$t_accessible_custom_fields_names = array();
-	$t_accessible_custom_fields_values = array();
 	$t_filter_cols = 7;
 	$t_custom_cols = 1;
 	$t_custom_rows = 0;
 
-	if ( ON == config_get( 'filter_by_custom_fields' ) ) {
-		$t_custom_cols = config_get( 'filter_custom_fields_per_row' );
-		$t_custom_fields = custom_field_get_ids( $t_project_id );
-
-		foreach ( $t_custom_fields as $t_cfid ) {
-			$t_field_info = custom_field_cache_row( $t_cfid, true );
-			if ( $t_field_info['access_level_r'] <= $t_current_user_access_level ) {
-				$t_accessible_custom_fields_ids[] = $t_cfid;
-				$t_accessible_custom_fields_names[] = $t_field_info['name'];
-				$t_accessible_custom_fields_values[] = custom_field_distinct_values( $t_cfid, $t_project_id );
-			}
-		}
-
-		if ( sizeof( $t_accessible_custom_fields_ids ) > 0 ) {
-			$t_per_row = config_get( 'filter_custom_fields_per_row' );
-			$t_custom_rows = ceil( sizeof( $t_accessible_custom_fields_ids ) / $t_per_row );
-		}
-	}		
-
 	$f_for_screen = gpc_get_bool( 'for_screen', true );
 
 	$t_sort = $t_filter['sort'];
 	$t_dir = $t_filter['dir'];
 	$t_action  = "view_all_set.php?f=3";
 
-	if ( $f_for_screen == false ) 
-	{
+	if ( $f_for_screen == false ) {
 		$t_action  = "view_all_set.php";
 	}
 
@@ -124,6 +129,9 @@
 	if ( SIMPLE_ONLY == config_get( 'view_filters' ) ) {
 		$f_view_type = 'simple';
 	}
+	if ( ! in_array( $f_view_type, array( 'simple', 'advanced' ) ) ) {
+		$f_view_type = $f_default_view_type;
+	}	
 
 	$t_select_modifier = '';
 	if ( 'advanced' == $f_view_type ) {
